@@ -26,6 +26,7 @@
 #include <glib.h>
 
 #include "tracker-uri.h"
+#include "tracker-utils.h"
 
 /* The TrackerUri GType is useful when encapsulating a URI inside a GValue.
  * When we generate SPARQL we need to treat URIs differently to normal strings
@@ -47,15 +48,6 @@ tracker_uri_get_type (void)
 	return g_define_type_id__volatile;
 }
 
-gchar *
-tracker_sparql_escape_uri_vprintf (const gchar *format,
-                                   va_list      args);
-gchar *
-tracker_sparql_escape_uri_printf  (const gchar* format,
-                                   ...);
-gchar *
-tracker_sparql_escape_uri         (const gchar *uri);
-
 static const char *
 find_conversion (const char  *format,
                  const char **after)
@@ -167,7 +159,7 @@ find_conversion (const char  *format,
  *
  * The result is escaped using g_uri_escape_string().
  *
- * Returns: (transfer-full): a newly-allocated string holding the result. The returned string
+ * Returns: (transfer full): a newly-allocated string holding the result. The returned string
  * should be freed with g_free() when no longer needed.
  *
  * Since: 0.10
@@ -271,7 +263,7 @@ cleanup:
  *
  * Calls tracker_sparql_escape_uri_vprintf() with the @... supplied.
  *
- * Returns: (transfer-full): a newly-allocated string holding the result.The returned string
+ * Returns: (transfer full): a newly-allocated string holding the result.The returned string
  * should be freed with g_free() when no longer needed.
  *
  * Since: 0.10
@@ -295,7 +287,7 @@ tracker_sparql_escape_uri_printf (const gchar *format, ...)
  *
  * Calls tracker_sparql_escape_uri_printf().
  *
- * Returns: (transfer-full): a newly-allocated string holding the result. The returned string
+ * Returns: (transfer full): a newly-allocated string holding the result. The returned string
  * should be freed with g_free() when no longer needed.
  *
  * Since: 1.12
